DisplayWriter

Struct DisplayWriter 

pub struct DisplayWriter<W: Write> { /* private fields */ }
DisplayWriter allows control of output to terminal or other Writer

Mainly for watch mode to allow control of output

Implementations

Source

impl<W: Write> DisplayWriter<W>

pub fn new(inner: W) -> Self

Create a new DisplayWriter with the inner writer

pub fn set_raw_mode(&mut self, raw_mode: bool)

Set the raw mode for the writer

Raw mode will print \r\n instead of \n for newlines

pub fn print<S: AsRef<str>>(&mut self, text: S) -> Result<()>

Print text to the writer

pub fn println<S: AsRef<str>>(&mut self, text: S, item: LineItem) -> Result<()>

Print text to the writer with a newline

pub fn into_inner(self) -> W

Get the inner writer

pub fn line_context(&self) -> &Vec<LineItem>

Get the line context for the writer

pub fn print_endpoints( &mut self, interface: &Interface, blocks: &[EndpointBlocks], settings: &PrintSettings, tree: &TreeData, dimmed: bool, )

All device Endpoint

pub fn print_interfaces( &mut self, interfaces: &[Interface], blocks: (&Vec<InterfaceBlocks>, &Vec<EndpointBlocks>), settings: &PrintSettings, tree: &TreeData, dimmed: bool, )

All device Interface

pub fn print_configurations( &mut self, device: &Device, configs: &[Configuration], blocks: (&Vec<ConfigurationBlocks>, &Vec<InterfaceBlocks>, &Vec<EndpointBlocks>), settings: &PrintSettings, tree: &TreeData, )

All device Configuration

pub fn print_devices( &mut self, devices: &[Device], db: &Vec<DeviceBlocks>, settings: &PrintSettings, tree: &TreeData, padding: &HashMap<DeviceBlocks, usize>, )

Recursively print devices; will call for each Device devices if Some

Will draw tree if settings.tree, otherwise it will be flat

pub fn print_sp_usb(&mut self, sp_usb: &SystemProfile, settings: &PrintSettings)

Print SystemProfile Bus and Device information

pub fn print_flattened_devices( &mut self, devices: &[&Device], settings: &PrintSettings, )

Print devices Device references without looking down each device’s devices!

pub fn print_bus_grouped( &mut self, bus_devices: Vec<(&Bus, Vec<&Device>)>, settings: &PrintSettings, )

A way of printing a reference flattened SystemProfile rather than hard flatten

Prints each &Bus and tuple pair Vec<&Device>