Bus

Struct Bus 

pub struct Bus {
    pub name: String,
    pub host_controller: String,
    pub host_controller_vendor: Option<String>,
    pub host_controller_device: Option<String>,
    pub pci_vendor: Option<u16>,
    pub pci_device: Option<u16>,
    pub pci_revision: Option<u16>,
    pub usb_bus_number: Option<u8>,
    pub devices: Option<Vec<Device>>,
    /* private fields */
}
USB bus returned from system_profiler but now used for other platforms.

It is a merging of the PCI Host Controller information and root hub device data (if present). Essentially a root hub but not as a pseudo device but an explicit type - since the root hub is a bit confusing in that sense.

Fields

name: String

System internal bus name based on Root Hub device name

Normally something generic like ‘Root Hub’, ‘USB 3.0 Bus’

host_controller: String

System internal bus provider name

host_controller_vendor: Option<String>

Vendor name of PCI Host Controller from pci.ids

host_controller_device: Option<String>

Device name of PCI Host Controller from pci.ids

pci_vendor: Option<u16>

PCI vendor ID (VID)

pci_device: Option<u16>

PCI device ID (PID)

pci_revision: Option<u16>

PCI Revsision ID

usb_bus_number: Option<u8>

Number of bus on system

devices: Option<Vec<Device>>

Devices on the Bus. Since a device can have devices too, need to walk down all devices to get all devices on the bus

On Linux, the root hub is also included in this list

Implementations

Source

impl Bus

Returns of Vec of devices in the Bus as a reference

pub fn len(&self) -> usize

Returns total number of devices in the bus

pub fn into_flattened_devices(&mut self)

Flattens the bus by copying each device into a new devices Vec

Unlike the flattened_devices which returns references that may still contain a Vec of Device, this function makes those None too since it is doing a hard copy.

Not very pretty or efficient, probably a better way…

pub fn flattened_devices(&self) -> Vec<&Device>

Returns a flattened Vec of references to all Devices on the bus

Note that whilst Vec of references is flat, the Devices still contain a devices Vec where the references point; recursive functions on the returned Vec will produce weird results

pub fn is_empty(&self) -> bool

Whether the bus has no Devices

pub fn has_empty_hubs(&self) -> bool

Whether the bus has just empty hubs

pub fn get_bus_number(&self) -> Option<u8>

usb_bus_number is not always present in system_profiler output so try to get from first device instead

pub fn path(&self) -> Option<PathBuf>

syspath style path to bus

pub fn interface(&self) -> Option<DevicePath>

sysfs style path to bus interface

pub fn remove_root_hub_device(&mut self)

Remove the root_hub if existing in bus

pub fn get_root_hub_device(&self) -> Option<&Device>

Gets the device that is the root_hub associated with this bus - Linux only but exists in case of using –from-json

pub fn get_root_hub_device_mut(&mut self) -> Option<&mut Device>

Gets a mutable device that is the root_hub associated with this bus - Linux only but exists in case of using –from-json

pub fn get_node(&self, port_path: &PortPath) -> Option<&Device>

Search for Device in branches of bus and return reference

pub fn get_node_mut(&mut self, port_path: &PortPath) -> Option<&mut Device>

Search for Device in branches of bus and return mutable if found

pub fn get_node_by_path<P: AsRef<Path>>(&self, port_path: P) -> Option<&Device>

Search for Device in branches of bus by Path and return reference

pub fn get_node_path_by_path_mut<P: AsRef<Path>>( &mut self, port_path: P, ) -> Option<&mut Device>

Search for Device in branches of bus by Path and return mutable reference

pub fn get_node_by_str(&self, path: &str) -> Option<&Device>

Search for reference to Device at port path as string

pub fn get_node_str_mut(&mut self, path: &str) -> Option<&mut Device>

Search for mutable reference to Device at port path as string

pub fn get_config( &self, port_path: &PortPath, config: u8, ) -> Option<&Configuration>

Get reference to Configuration at PortPath and config if present

pub fn get_config_mut( &mut self, port_path: &PortPath, config: u8, ) -> Option<&mut Configuration>

Get mutable reference to Configuration at PortPath and config if present

pub fn get_interface(&self, device_path: &DevicePath) -> Option<&Interface>

Get reference to Interface at DevicePath if config and interface are present

pub fn get_interface_mut( &mut self, device_path: &DevicePath, ) -> Option<&mut Interface>

Get mutable reference to Interface at DevicePath if config and interface are present

pub fn get_endpoint(&self, endpoint_path: &EndpointPath) -> Option<&Endpoint>

Get reference to Endpoint at EndpointPath if config and interface are present

pub fn get_endpoint_mut( &mut self, endpoint_path: &EndpointPath, ) -> Option<&mut Endpoint>

Get mutable reference to Endpoint at EndpointPath if config and interface are present

pub fn get_id(&self, id: &DeviceId) -> Option<&Device>

Search for ::nusb::DeviceId in branches of bus and return reference

pub fn get_id_mut(&mut self, id: &DeviceId) -> Option<&mut Device>

Search for ::nusb::DeviceId in branches of bus and returns a mutable reference if found

pub fn to_lsusb_string(&self) -> String

Generate a String from self like lsusb default list device

pub fn to_lsusb_tree_string(&self, verbosity: u8) -> Vec<String>

Generate a Vec of Strings from self in lsusb tree self in order of verbosity

Only Linux systems with a root_hub will contain accurate data, others are mainly for styling

pub fn is_hidden(&self) -> bool

Should the bus be hidden when printing

pub fn is_expanded(&self) -> bool

Should the bus be expanded when printing

pub fn toggle_expanded(&mut self)

Toggle the expanded state of the bus

pub fn set_all_expanded(&mut self, expanded: bool)

Set the expanded state of the bus and all devices