pub struct DeviceLocation {
pub bus: u8,
pub tree_positions: Vec<u8>,
pub number: u8,
}Expand description
location_id String from system_profiler is “LocationReg / DeviceNo”
The LocationReg has the tree structure (0xbbdddddd):
0x – always bb – bus number in hexadecimal dddddd – up to six levels for the tree, each digit represents its position on that level
Fields
bus: u8Number of bus attached too
tree_positions: Vec<u8>Length is depth in tree and position at each branch, empty is bus controller
number: u8Device number on bus, generally not related to tree