SystemProfile

Struct SystemProfile 

pub struct SystemProfile {
    pub buses: Vec<Bus>,
}
Root JSON returned from system_profiler and used as holder for all static USB bus data

Fields

buses: Vec<Bus>

system buses

Implementations

Source

impl SystemProfile

pub fn len(&self) -> usize

Returns total number of devices across all buses

pub fn is_empty(&self) -> bool

Whether all buses are empty

pub fn into_flattened(&mut self)

Flattens all Buses by calling into_flattened_devices on each

In place operation so it mutates the data and tree structure is lost. Location data is still present in each device.

pub fn flattened_devices(&self) -> Vec<&Device>

Returns a flattened Vec of references to all Devices in each of the buses

pub fn get_bus(&self, number: u8) -> Option<&Bus>

Returns reference to Bus number if it exists in data

pub fn get_bus_mut(&mut self, number: u8) -> Option<&mut Bus>

Returns mutable reference to Bus number if it exists in data

pub fn get_node(&self, port_path: &PortPath) -> Option<&Device>

Search for reference to Device at PortPath on correct bus number if present else all buses

pub fn get_node_mut(&mut self, port_path: &PortPath) -> Option<&mut Device>

Search for mutable reference to Device at PortPath on correct bus number if present else all buses

pub fn get_node_by_path<P: AsRef<Path>>(&self, path: P) -> Option<&Device>

Search for reference to Device at port_path as Path

pub fn get_node_path_by_path_mut<P: AsRef<Path>>( &mut self, path: P, ) -> Option<&mut Device>

Search for mutable reference to Device at port_path as Path

pub fn get_node_by_str(&self, path: &str) -> Option<&Device>

Search for reference to Device at port path as string

pub fn get_node_str_mut(&mut self, path: &str) -> Option<&mut Device>

Search for mutable reference to Device at port path as string

pub fn get_config( &self, port_path: &PortPath, config: u8, ) -> Option<&Configuration>

Get reference to Configuration at port_path and config if present

pub fn get_config_mut( &mut self, port_path: &PortPath, config: u8, ) -> Option<&mut Configuration>

Get mutable reference to Configuration at PortPath and config if present

pub fn get_interface(&self, device_path: &DevicePath) -> Option<&Interface>

Get reference to Interface at port_path, config and interface if present in DevicePath

pub fn get_interface_mut( &mut self, device_path: &DevicePath, ) -> Option<&mut Interface>

Get mutable reference to Interface at port_path, config and interface if present in DevicePath

pub fn get_endpoint(&self, endpoint_path: &EndpointPath) -> Option<&Endpoint>

Get reference to Endpoint at port_path, config, interface and endpoint if present

pub fn get_endpoint_mut( &mut self, endpoint_path: &EndpointPath, ) -> Option<&mut Endpoint>

Get mutable reference to Endpoint at port_path, config, interface and endpoint if present

pub fn get_id(&self, id: &DeviceId) -> Option<&Device>

Search for ::nusb::DeviceId in branches of bus and return reference

pub fn get_id_mut(&mut self, id: &DeviceId) -> Option<&mut Device>

Search for ::nusb::DeviceId in branches of bus and returns a mutable reference if found

pub fn replace(&mut self, new: Device) -> Result<Device>

Replace a Device in the correct Bus and parent device based on its location_id

If the device was existing, it will be replaced with the old device and returned as Ok, else Err if the device was not found.

pub fn insert(&mut self, new: Device) -> Option<Device>

Insert a Device into the correct Bus and parent device based on its location_id

If the device was existing, it will be replaced with the new device and returned as Some (without child devices), else None. None will also be returned if the device parent is not found.